# Conexións
[![GitHub license](https://img.shields.io/github/license/Ran-n/scripts)](https://github.com/Ran-n/scripts/blob/master/LICENSE)
![PowerShell Gallery](https://img.shields.io/badge/plataforma-LiGNUx%20%7C%20Windows10-lightgrey)

[![GitHub issues](https://img.shields.io/github/issues/Ran-n/conexions)](https://github.com/Ran-n/conexions/issues)
[![GitHub forks](https://img.shields.io/github/forks/Ran-n/conexions)](https://github.com/Ran-n/conexions/network)
[![GitHub stars](https://img.shields.io/github/stars/Ran-n/conexions)](https://github.com/Ran-n/conexions/stargazers)

[Ran-n/conexions](https://github.com/Ran-n/conexions)

Módulo de conexións que scrapea e usa os proxies da páxina de "sslproxies.org".
Por defecto non ten verbose, ten un máximo de 20 conexións por ip e 30 segundos de espera por get.


## [Donations 🙇🙇‍♀](https://github.com/Ran-n/doc/blob/main/doaz%C3%B3ns.md)

**Bitcoin** <img src="https://raw.githubusercontent.com/Ran-n/svgs/main/divisas/bitcoin/bitcoin_0.svg" width="20" alt="bitcoin logo" title="Bitcoin">  
bc1q79vja8jzr27dxaf3ylu7e49ady8zq0jsm5qfk6

**Monero** <img src="https://raw.githubusercontent.com/Ran-n/svgs/main/divisas/monero/monero_0.svg" width="20" alt="monero logo" title="Monero">  
88Rezd6ZQzaCb1s7K1tRCiCaDzuHrfYsn4q348jJuePpLs84JNsWEghMAZZgzpDPrqD4PBxk7hwMkSdNQ4CLqFHyPVLdX1D

**Wownero** <img src="https://raw.githubusercontent.com/Ran-n/svgs/main/divisas/wownero/wownero_0.svg" width="20" alt="wownero logo" title="Wownero">  
WW2RheTNrq8goAi42Dz5AKUj1qLSaTSSgiH7sHR2qRqojg238EXP3MM3xuUgswriET7UrpkEoYaCkecBhnU49oxM1dZyYoSmm
